@@ -1,6 +1,6 @@
 /*
     apfs.c -- parted support for apfs file systems
-    Copyright (C) 1998-2000, 2007 Free Software Foundation, Inc.
+    Copyright (C) 1998-2000, 2007, 2009-2011 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,19 +44,18 @@ _generic_apfs_probe (PedGeometry* geom, uint32_t kind)
 	uint32_t *block;
 	PedSector root;
 	struct PartitionBlock * part;
-	uint32_t blocksize = 1, reserved = 2, prealloc = 0;
+	uint32_t blocksize = 1, reserved = 2;
 
-	PED_ASSERT (geom != NULL, return NULL);
-	PED_ASSERT (geom->dev != NULL, return NULL);
+	PED_ASSERT (geom != NULL);
+	PED_ASSERT (geom->dev != NULL);
 
-	/* Finds the blocksize, prealloc and reserved values of the partition block */
+	/* Finds the blocksize and reserved values of the partition block */
 	if (!(part = ped_malloc (PED_SECTOR_SIZE_DEFAULT*blocksize))) {
 		ped_exception_throw(PED_EXCEPTION_ERROR, PED_EXCEPTION_CANCEL,
 			_("%s : Failed to allocate partition block\n"), __func__);
 		goto error_part;
 	}
 	if (amiga_find_part(geom, part) != NULL) {
-		prealloc = PED_BE32_TO_CPU (part->de_PreAlloc);
 		reserved = PED_BE32_TO_CPU (part->de_Reserved);
 		blocksize = PED_BE32_TO_CPU (part->de_SizeBlock)
 			* PED_BE32_TO_CPU (part->de_SectorPerBlock) / 128;
