@@ -1,7 +1,6 @@
 /*
     ext2_inode_relocator.c -- ext2 inode relocator
-    Copyright (C) 1998-2000, 2007, 2009-2010 Free Software Foundation,
-    Inc.
+    Copyright (C) 1998-2000, 2007, 2009-2011 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -146,7 +145,7 @@ static int doblock(struct ext2_fs *fs, struct ext2_inode_relocator_state *state,
 				    offset))
 				return 0;
 
-		PED_ASSERT (ptr->rec_len > 0, return 0);
+		PED_ASSERT (ptr->rec_len > 0);
 		offset += EXT2_DIRENT_REC_LEN (*ptr);
 	} while (offset < fs->blocksize);
 
@@ -597,4 +596,3 @@ int ext2_inode_relocate(struct ext2_fs *fs, int newgroups)
 	return 1;
 }
 #endif /* !DISCOVER_ONLY */
-
