@@ -1,6 +1,6 @@
 /*
     interface.c -- parted binding glue to libext2resize
-    Copyright (C) 1998-2000, 2007-2010 Free Software Foundation, Inc.
+    Copyright (C) 1998-2000, 2007-2011 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -54,12 +54,16 @@ _ext2_generic_probe (PedGeometry* geom, int expect_ext_ver)
 		if (is_ext3) {
 			is_ext4 = ((EXT2_SUPER_FEATURE_RO_COMPAT (*sb)
 				    & EXT4_FEATURE_RO_COMPAT_HUGE_FILE)
+				   || (EXT2_SUPER_FEATURE_RO_COMPAT (*sb)
+				       & EXT4_FEATURE_RO_COMPAT_GDT_CSUM)
 				   || (EXT2_SUPER_FEATURE_RO_COMPAT (*sb)
 				       & EXT4_FEATURE_RO_COMPAT_DIR_NLINK)
 				   || (EXT2_SUPER_FEATURE_INCOMPAT (*sb)
 				       & EXT4_FEATURE_INCOMPAT_EXTENTS)
 				   || (EXT2_SUPER_FEATURE_INCOMPAT (*sb)
-				       & EXT4_FEATURE_INCOMPAT_64BIT));
+				       & EXT4_FEATURE_INCOMPAT_64BIT)
+				   || (EXT2_SUPER_FEATURE_INCOMPAT (*sb)
+				       & EXT4_FEATURE_INCOMPAT_FLEX_BG));
 			if (is_ext4)
 				is_ext3 = 0;
 		}
@@ -230,7 +234,7 @@ _ext2_resize (PedFileSystem* fs, PedGeometry* geom, PedTimer* timer)
 	struct ext2_fs* f;
 	PedSector	old_length = fs->geom->length;
 
-	PED_ASSERT (fs->geom->dev == geom->dev, return 0);
+	PED_ASSERT (fs->geom->dev == geom->dev);
 
 	if (fs->geom->start != geom->start)
 	{
