@@ -1,6 +1,7 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2000, 2003-2005, 2007, 2009 Free Software Foundation, Inc.
+    Copyright (C) 2000, 2003-2005, 2007, 2009-2011 Free Software Foundation,
+    Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -202,17 +203,17 @@ hfs_resize (PedFileSystem* fs, PedGeometry* geom, PedTimer* timer)
 	PedSector		hgee;
 
 	/* check preconditions */
-	PED_ASSERT (fs != NULL, return 0);
-	PED_ASSERT (fs->geom != NULL, return 0);
-	PED_ASSERT (geom != NULL, return 0);
+	PED_ASSERT (fs != NULL);
+	PED_ASSERT (fs->geom != NULL);
+	PED_ASSERT (geom != NULL);
 #ifdef DEBUG
-        PED_ASSERT ((hgee = hfs_get_empty_end(fs)) != 0, return 0);
+        PED_ASSERT ((hgee = hfs_get_empty_end(fs)) != 0);
 #else
         if ((hgee = hfs_get_empty_end(fs)) == 0)
                 return 0;
 #endif
 
-	PED_ASSERT ((hgee = hfs_get_empty_end(fs)) != 0, return 0);
+	PED_ASSERT ((hgee = hfs_get_empty_end(fs)) != 0);
 
 	if (ped_geometry_test_equal(fs->geom, geom))
 		return 1;
@@ -914,12 +915,12 @@ hfsplus_resize (PedFileSystem* fs, PedGeometry* geom, PedTimer* timer)
 	PedSector		hgms;
 
 	/* check preconditions */
-	PED_ASSERT (fs != NULL, return 0);
-	PED_ASSERT (fs->geom != NULL, return 0);
-	PED_ASSERT (geom != NULL, return 0);
-	PED_ASSERT (fs->geom->dev == geom->dev, return 0);
+	PED_ASSERT (fs != NULL);
+	PED_ASSERT (fs->geom != NULL);
+	PED_ASSERT (geom != NULL);
+	PED_ASSERT (fs->geom->dev == geom->dev);
 #ifdef DEBUG
-        PED_ASSERT ((hgms = hfsplus_get_min_size (fs)) != 0, return 0);
+        PED_ASSERT ((hgms = hfsplus_get_min_size (fs)) != 0);
 #else
         if ((hgms = hfsplus_get_min_size (fs)) == 0)
                 return 0;
