@@ -1,6 +1,6 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2001, 2007, 2009-2010 Free Software Foundation, Inc.
+    Copyright (C) 2001, 2007, 2009-2011 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -310,7 +310,7 @@ static PedFileSystemType ufs_type_hp = {
 void
 ped_file_system_ufs_init ()
 {
-	PED_ASSERT (sizeof (struct ufs_super_block) == 1380, return);
+	PED_ASSERT (sizeof (struct ufs_super_block) == 1380);
 
 	ped_file_system_type_register (&ufs_type_sun);
 	ped_file_system_type_register (&ufs_type_hp);
