@@ -1,6 +1,6 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 1999-2001, 2007-2009 Free Software Foundation, Inc.
+    Copyright (C) 1999-2001, 2007-2011 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -109,6 +109,7 @@ extern void ped_file_system_jfs_init (void);
 extern void ped_file_system_hfs_init (void);
 extern void ped_file_system_fat_init (void);
 extern void ped_file_system_ext2_init (void);
+extern void ped_file_system_nilfs2_init (void);
 
 static void
 init_file_system_types ()
@@ -123,6 +124,7 @@ init_file_system_types ()
 	ped_file_system_hfs_init ();
 	ped_file_system_fat_init ();
 	ped_file_system_ext2_init ();
+	ped_file_system_nilfs2_init ();
 }
 #endif /* ENABLE_FS */
 
@@ -179,6 +181,7 @@ _init()
 }
 
 #ifdef ENABLE_FS
+extern void ped_file_system_nilfs2_done (void);
 extern void ped_file_system_ext2_done (void);
 extern void ped_file_system_fat_done (void);
 extern void ped_file_system_hfs_done (void);
@@ -193,6 +196,7 @@ extern void ped_file_system_amiga_done (void);
 static void
 done_file_system_types ()
 {
+	ped_file_system_nilfs2_done ();
 	ped_file_system_ext2_done ();
 	ped_file_system_fat_done ();
 	ped_file_system_hfs_done ();
