@@ -1,6 +1,7 @@
 #!/bin/sh
+# run the disk unit tests in a directory supporting O_DIRECT
 
-# Copyright (C) 2007-2009 Free Software Foundation, Inc.
+# Copyright (C) 2007-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,14 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-test_description='run the disk unit tests in a directory supporting O_DIRECT'
 # This wrapper around the ./label binary is used to find a directory
 # in which one can open a file with the O_DIRECT flag.
 
-: ${top_srcdir=../..}
-. "$top_srcdir/tests/test-lib.sh"
+. "${top_srcdir=../..}/tests/init.sh"; path_prepend_ .
 
-test_expect_success \
-    'run the actual tests' 'disk'
+disk || fail=1
 
-test_done
+Exit $fail
