@@ -1,7 +1,7 @@
 # Put lvm-related utilities here.
-# This file is sourced from test-lib.sh.
+# This file is sourced from test infrastructure.
 
-# Copyright (C) 2007-2009 Red Hat, Inc. All rights reserved.
+# Copyright (C) 2007-2010 Red Hat, Inc. All rights reserved.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions
@@ -21,7 +21,7 @@ unsafe_losetup_()
   f=$1
 
   test -n "$G_dev_" \
-    || error "Internal error: unsafe_losetup_ called before init_root_dir_"
+    || fail_ "Internal error: unsafe_losetup_ called before init_root_dir_"
 
   # Iterate through $G_dev_/loop{,/}{0,1,2,3,4,5,6,7,8,9}
   for slash in '' /; do
@@ -149,19 +149,19 @@ dmsetup_has_dm_devdir_support_()
   # Detect support for the envvar.  If it's supported, the
   # following command will fail with the expected diagnostic.
   out=$(DM_DEV_DIR=j dmsetup version 2>&1)
-  test "$?:$out" = "1:Invalid DM_DEV_DIR envvar value." -o \
-       "$?:$out" = "1:Invalid DM_DEV_DIR environment variable value."
+  test "$?:$out" = "1:Invalid DM_DEV_DIR envvar value." ||
+  test "$?:$out" = "1:Invalid DM_DEV_DIR environment variable value."
 }
 
 # set up private /dev and /etc
 init_root_dir_()
 {
-  test -n "$test_dir_rand_" \
-    || error "Internal error: called init_root_dir_ before" \
-      "defining \$test_dir_rand_"
+  test -n "$test_dir_" \
+    || fail_ "Internal error: called init_root_dir_ before" \
+      "defining \$test_dir_"
 
   # Define these two globals.
-  G_root_=$test_dir_rand_/root
+  G_root_=$test_dir_/root
   G_dev_=$G_root_/dev
 
   export LVM_SYSTEM_DIR=$G_root_/etc
