@@ -1,7 +1,7 @@
 #!/bin/sh
 # operate on a very small (1-sector) "disk"
 
-# Copyright (C) 2009-2010 Free Software Foundation, Inc.
+# Copyright (C) 2009-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,19 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-if test "$VERBOSE" = yes; then
-  set -x
-  parted --version
-fi
-
-: ${srcdir=.}
-. $srcdir/t-lib.sh
+. "${srcdir=.}/init.sh"; path_prepend_ ../parted
 
 ss=$sector_size_
 dev=loop-file
 
-fail=0
-
 for opt in '' -s; do
 
   dd if=/dev/null of=$dev bs=1 seek=$ss || framework_failure
