@@ -2,7 +2,7 @@
 # avoid failed assertion when creating a GPT on top of an old one for a
 # larger device
 
-# Copyright (C) 2009 Free Software Foundation, Inc.
+# Copyright (C) 2009-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,15 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-if test "$VERBOSE" = yes; then
-  set -x
-  parted --version
-fi
-
-: ${srcdir=.}
-. $srcdir/t-lib.sh
-
-fail=0
+. "${srcdir=.}/init.sh"; path_prepend_ ../parted
 
 dev=loop-file
 # create a backing file large enough for a GPT partition table
