@@ -5,7 +5,7 @@
 # GPT/MBR table, merely listing the table with Parted-2.1 would clobber
 # the MBR part.
 
-# Copyright (C) 2010 Free Software Foundation, Inc.
+# Copyright (C) 2010-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,15 +20,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-if test "$VERBOSE" = yes; then
-  set -x
-  parted --version
-fi
-
-: ${srcdir=.}
-. $srcdir/t-lib.sh
-
-fail=0
+. "${srcdir=.}/init.sh"; path_prepend_ ../parted
 
 ss=$sector_size_
 n_sectors=400
