@@ -1,7 +1,7 @@
 #!/bin/sh
 # avoid segfault creating a dos PT on top of a gpt one
 
-# Copyright (C) 2009 Free Software Foundation, Inc.
+# Copyright (C) 2009-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,19 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-if test "$VERBOSE" = yes; then
-  set -x
-  parted --version
-fi
-
-: ${srcdir=.}
-. $srcdir/t-lib.sh
+. "${srcdir=.}/init.sh"; path_prepend_ ../parted
 
 PARTED_SECTOR_SIZE=4096
 export PARTED_SECTOR_SIZE
 
-fail=0
-
 dev=loop-file
 # create a backing file large enough for a GPT partition table
 dd if=/dev/null of=$dev seek=4001 2> /dev/null || framework_failure
