@@ -1,7 +1,7 @@
 #!/bin/sh
 # check physical sector size as reported by 'print'
 
-# Copyright (C) 2009-2010 Free Software Foundation, Inc.
+# Copyright (C) 2009-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,29 +16,21 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-if test "$VERBOSE" = yes; then
-  set -x
-  parted --version
-fi
-
-: ${srcdir=.}
-. $srcdir/t-lib.sh
+. "${srcdir=.}/init.sh"; path_prepend_ ../parted
 
 require_root_
 require_scsi_debug_module_
 
 grep '^#define USE_BLKID 1' "$CONFIG_HEADER" > /dev/null ||
-  skip_test_ 'this system lacks a new-enough libblkid'
+  skip_ 'this system lacks a new-enough libblkid'
 
 echo 'Sector size (logical/physical): 4096B/4096B' > exp || framework_failure
 
 # create memory-backed device
 scsi_debug_setup_ dev_size_mb=8 sector_size=4096 > dev-name ||
-  skip_test_ 'failed to create scsi_debug device'
+  skip_ 'failed to create scsi_debug device'
 scsi_dev=$(cat dev-name)
 
-fail=0
-
 # create partition table and print
 parted -s $scsi_dev mklabel gpt print > out 2>&1 || fail=1
 grep '^Sector' out > k 2>&1 || fail=1
